import {scaleOrdinal} from 'd3';

const colorScale = scaleOrdinal()
				.domain(['apple', 'lemon'])
				.range(['red', 'yellow'])
			;

const radiusScale = scaleOrdinal()
				.domain(['apple', 'lemon'])
				.range([50, 30])
			;

export const fruitBowl = (selection, props) => {
  const {fruits, height} = props;
  
  const xPosition = (d, i) => i * 180 + 100;
  
  const bowl = selection.selectAll('rect')
  				.data([null])
  				.enter()
            .append('rect')
            .attr('y', 110)
            .attr('width', 900)
            .attr('height', 300)
            .attr('rx', 300 / 2)
  			;
  
  //==
  const groups = selection.selectAll('g')
			//.data(fruits);
  		.data(fruits); //important to keep obj consistancy
  const groupsEnter = groups.enter().append('g');
  groupsEnter
  	.merge(groups)
  		.attr('transform', (d, i) =>
            `translate(${i * 180 + 100}, ${height / 2})`);
  groups.exit().remove();
  //==

  //alternative way
  // groups.select('circle')
  // 	.merge(groupsEnter.append('circle'))
  // 		.attr('r', d => radiusScale(d.type))
  // 		.attr('fill', d => colorScale(d.type));
  
	groupsEnter.append('circle')
  	
  	.merge(groups.select('circle'))
  		.attr('fill', d => colorScale(d.type))
  		.attr('r', d => radiusScale(d.type))
  	;
  		

  groupsEnter.append('text')
  	.merge(groups.select('text'))
  		.text(d => d.type)
  		.attr('y', 100)
  		.attr('fill', d => colorScale(d.type)); 
  	;
 

}

